==> imsurvey-1.2-20170418.133909-153-sources.jar: com/imcode/imcms/addon/imsurvey/utils/OneflowFields.java <==
package com.imcode.imcms.addon.imsurvey.utils;

import com.imcode.imcms.addon.imsurvey.FormEngine;

/**
 * Container of sting constants which is used in OneflowServicez
 * Created by dmizem from Ubrainians for ImCode on 31.01.17
 *
 * @author dmizem
 * @see com.imcode.imcms.addon.imsurvey.oneflow.OneflowService
 */
public class OneflowFields {

    //Queries
    public static final String QUERY_ELEMENT_ID_BY_META_ID = "SELECT el.id \n" +
            "FROM " + FormEngine.TABLE_PREFIX + "form_elements el \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "form_elements_options opt ON el.id = opt.el_id \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "element_scrive_fields el_fields ON el_fields.`element_id` = el.id \n" +
            "WHERE el.meta_id = ? AND el.el_type = 'oneflow_user'" +
            " LIMIT 1";

    public static final String QUERY_TEMPLATE_USERS = "SELECT opt.el_text, opt.el_id, opt.id \n" +
            "FROM " + FormEngine.TABLE_PREFIX + "form_elements el \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "form_elements_options opt ON el.id = opt.el_id \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "element_scrive_fields el_fields ON el_fields.`element_id` = el.id \n" +
            "WHERE el.meta_id = ? AND el.el_type = 'oneflow_user'";

    public static final String QUERY_ELEMENT_TEMPLATE_FIELDS = "SELECT * FROM " + FormEngine.TABLE_PREFIX + "element_scrive_fields WHERE element_id = ?";

    public static final String QUERY_ELEMENT_OPTIONS_TEMPLATE_FIELDS = "SELECT * FROM " + FormEngine.TABLE_PREFIX + "element_option_scrive_fields WHERE option_id = ?";

    //  SQL field names
    public static final String SQL_TEMPLATE_ID = "template_id";
    public static final String SQL_FIELD_NAME = "field_name";
    public static final String SQL_EL_TEXT = "el_text";
    public static final String SQL_ID = "id";

    //  API URL's
    public static final String API_AGREEMENTS_URL = "/api/agreements/";
    public static final String API_TEMPLATE_GROUPS_URL = "/api/ext/templategroups/";
    public static final String API_TEMPLATE_GROUP_BY_ID_URL = "/api/templates/?template_group_id=";
    public static final String API_DATA_SET_URL = "/api/data_field_sets/";

    //  JSON field names
    public static final String JSON_ID = "id";
    public static final String JSON_TEMPLATE_ID = "template_id";
    public static final String JSON_SELF = "self";
    public static final String JSON_POSITION_ID = "position_id";
    public static final String JSON_PARTICIPANTS = "participants";
    public static final String JSON_PARTIES = "parties";
    public static final String JSON_DATA_FIELD = "data_field";
    public static final String JSON_EXTERNAL_KEY = "external_key";
    public static final String JSON_VALUE = "value";
    public static final String JSON_KEY = "key";
    public static final String JSON_DATA = "data";
    public static final String JSON_SUBJECT = "subject";
    public static final String JSON_MESSAGE = "message";
    public static final String JSON_AVAILABLE_OPTIONS = "available_options";
    public static final String JSON_DELIVERY_CHANNELS = "delivery_channels";
    public static final String JSON_SIGN_METHODS = "sign_methods";
    public static final String JSON_COLLECTION = "collection";
    public static final String JSON_NAME = "name";
    public static final String JSON_DATA_FIELD_SET = "data_field_set";
    public static final String JSON_AGREEMENT = "agreement";
    public static final String JSON_DATA_FIELDS = "data_fields";
    public static final String JSON_TYPE = "type";
    public static final String JSON_TOKEN = "token";
    public static final String JSON_TEMPLATE_GROUP = "template_group";
    public static final String JSON_FORM = "form";

    //  Constants
    public static final String PROPERTY_IM_SURVEY_ID = "imSurveyId";
    public static final int DEFAULT_INT_VALUE = -1;

    //  Regex patterns
    public static final String REGEX_TEMPLATE_ID = "[0-9]+";
    public static final String REGEX_USER_FIELD = "user_[0-9]+_.+";
    public static final String REGEX_USER_DATA_BY_GROUPS = "_([0-9]+)_(.+)";
    public static final String REGEX_USER_DIVIDER = "user_";

    //  Error messages
    public static final String ERROR_WRONG_TEMPLATE_ID = "Oneflow template id is either missing or invalid: ";
    public static final String ERROR_TEMPLATE_CHANGED = "Error template has changed! Can't create document.";
    public static final String ERROR_OBTAIN_DELIVERY_METHOD = "Can't obtain delivery method for agreement: ";

    //Publication texts
    public static final String PUBLICATION_SUBJECT = "Babs Paylink - Avtal att signera";
    public static final String PUBLICATION_MESSAGE = "Hej! <br />Roligt att du vill bli kund hos oss.<br />Vänligen läs igenom och signera ditt avtal.";
}

==> imsurvey-1.4-20181018.133632-21-sources.jar: com/imcode/imcms/addon/imsurvey/utils/OneflowFields.java <==
package com.imcode.imcms.addon.imsurvey.utils;

import com.imcode.imcms.addon.imsurvey.FormEngine;

/**
 * Container of sting constants which is used in OneflowServicez
 * Created by dmizem from Ubrainians for ImCode on 31.01.17
 *
 * @author dmizem
 * @see com.imcode.imcms.addon.imsurvey.oneflow.OneflowService
 */
public class OneflowFields {

    //Queries
    public static final String QUERY_ELEMENT_ID_BY_META_ID = "SELECT el.id \n" +
            "FROM " + FormEngine.TABLE_PREFIX + "form_elements el \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "form_elements_options opt ON el.id = opt.el_id \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "element_scrive_fields el_fields ON el_fields.`element_id` = el.id \n" +
            "WHERE el.meta_id = ? AND el.el_type = 'oneflow_user'" +
            " LIMIT 1";

    public static final String QUERY_TEMPLATE_USERS = "SELECT opt.el_text, opt.el_id, opt.id \n" +
            "FROM " + FormEngine.TABLE_PREFIX + "form_elements el \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "form_elements_options opt ON el.id = opt.el_id \n" +
            "LEFT JOIN " + FormEngine.TABLE_PREFIX + "element_scrive_fields el_fields ON el_fields.`element_id` = el.id \n" +
            "WHERE el.meta_id = ? AND el.el_type = 'oneflow_user'";

    public static final String QUERY_ELEMENT_TEMPLATE_FIELDS = "SELECT * FROM " + FormEngine.TABLE_PREFIX + "element_scrive_fields WHERE element_id = ?";

    public static final String QUERY_ELEMENT_OPTIONS_TEMPLATE_FIELDS = "SELECT * FROM " + FormEngine.TABLE_PREFIX + "element_option_scrive_fields WHERE option_id = ?";

    //  SQL field names
    public static final String SQL_TEMPLATE_ID = "template_id";
    public static final String SQL_FIELD_NAME = "field_name";
    public static final String SQL_EL_TEXT = "el_text";
    public static final String SQL_ID = "id";

    //  API URL's
    public static final String API_AGREEMENTS_URL = "/api/agreements/";
    public static final String API_TEMPLATE_GROUPS_URL = "/api/ext/templategroups/";
    public static final String API_TEMPLATE_GROUP_BY_ID_URL = "/api/templates/?template_group_id=";
    public static final String API_DATA_SET_URL = "/api/data_field_sets/";

    //  JSON field names
    public static final String JSON_ID = "id";
    public static final String JSON_TEMPLATE_ID = "template_id";
    public static final String JSON_SELF = "self";
    public static final String JSON_POSITION_ID = "position_id";
    public static final String JSON_PARTICIPANTS = "participants";
    public static final String JSON_PARTIES = "parties";
    public static final String JSON_DATA_FIELD = "data_field";
    public static final String JSON_EXTERNAL_KEY = "external_key";
    public static final String JSON_VALUE = "value";
    public static final String JSON_KEY = "key";
    public static final String JSON_DATA = "data";
    public static final String JSON_SUBJECT = "subject";
    public static final String JSON_MESSAGE = "message";
    public static final String JSON_AVAILABLE_OPTIONS = "available_options";
    public static final String JSON_DELIVERY_CHANNELS = "delivery_channels";
    public static final String JSON_SIGN_METHODS = "sign_methods";
    public static final String JSON_COLLECTION = "collection";
    public static final String JSON_NAME = "name";
    public static final String JSON_DATA_FIELD_SET = "data_field_set";
    public static final String JSON_AGREEMENT = "agreement";
    public static final String JSON_DATA_FIELDS = "data_fields";
    public static final String JSON_TYPE = "type";
    public static final String JSON_TOKEN = "token";
    public static final String JSON_TEMPLATE_GROUP = "template_group";
    public static final String JSON_FORM = "form";

    //  Constants
    public static final String PROPERTY_IM_SURVEY_ID = "imSurveyId";
    public static final int DEFAULT_INT_VALUE = -1;

    //  Regex patterns
    public static final String REGEX_TEMPLATE_ID = "[0-9]+";
    public static final String REGEX_USER_FIELD = "user_[0-9]+_.+";
    public static final String REGEX_USER_DATA_BY_GROUPS = "_([0-9]+)_(.+)";
    public static final String REGEX_USER_DIVIDER = "user_";

    //  Error messages
    public static final String ERROR_WRONG_TEMPLATE_ID = "Oneflow template id is either missing or invalid: ";
    public static final String ERROR_TEMPLATE_CHANGED = "Error template has changed! Can't create document.";
    public static final String ERROR_OBTAIN_DELIVERY_METHOD = "Can't obtain delivery method for agreement: ";

    //Publication texts
    public static final String PUBLICATION_SUBJECT = "Babs Paylink - Avtal att signera";
    public static final String PUBLICATION_MESSAGE = "Hej! <br /><br />Roligt att du vill teckna avtal med oss.<br />Vänligen läs igenom och signera ditt avtal.<br /><br />Om du inte är juridisk part i detta avtal så behöver du inte göra något mer just nu.";
}
